summaryrefslogtreecommitdiffstats
path: root/kdat/OptionsDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/OptionsDlg.h')
-rw-r--r--kdat/OptionsDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/OptionsDlg.h b/kdat/OptionsDlg.h
index b96fe8c..75d29a9 100644
--- a/kdat/OptionsDlg.h
+++ b/kdat/OptionsDlg.h
@@ -39,10 +39,10 @@ public:
/**
* Create a new options dialog.
*
* @param tqparent The tqparent widget of the dialog.
* @param name The name of the dialog.
*/
- OptionsDlg( TQWidget* tqparent = 0, const char* name = 0 );
+ OptionsDlg( TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the options dialog.
@@ -39,10 +39,10 @@ public:
* Create a new options dialog.
*
- * @param tqparent The tqparent widget of the dialog.
+ * @param parent The parent widget of the dialog.
* @param name The name of the dialog.
*/